@@ -71,7 +71,6 @@ FILTER_FIELDS = R.compose(
         # Minimum set for debugging speed
         lambda _: {
             'contains': dict(),
-            'icontains': dict(),
             'in': dict(type_modifier=lambda typ: graphene.List(typ))
         },
         lambda _: {
@@ -85,23 +84,23 @@ FILTER_FIELDS = R.compose(
 
             # standard lookups
             'exact': dict(),  # this is the default, but keep so we can do negative queries, i.e. exact__not
-            'iexact': dict(),
+            #'iexact': dict(),
             'contains': dict(),
-            'icontains': dict(),
+            #'icontains': dict(),
             'in': dict(type_modifier=lambda typ: graphene.List(typ)),
             'gt': dict(allowed_types=[graphene.Int, graphene.Float, graphene.DateTime, graphene.Date]),
             'gte': dict(allowed_types=[graphene.Int, graphene.Float, graphene.DateTime, graphene.Date]),
             'lt': dict(allowed_types=[graphene.Int, graphene.Float, graphene.DateTime, graphene.Date]),
             'lte': dict(allowed_types=[graphene.Int, graphene.Float, graphene.DateTime, graphene.Date]),
             'startswith': dict(allowed_types=[graphene.String]),
-            'istartswith': dict(allowed_types=[graphene.String]),
+            #'istartswith': dict(allowed_types=[graphene.String]),
             'endswith': dict(allowed_types=[graphene.String]),
-            'iendswith': dict(allowed_types=[graphene.String]),
+            #'iendswith': dict(allowed_types=[graphene.String]),
             # Range expects a 2 item tuple, so give it a list
             'range': dict(type_modifier=lambda typ: graphene.List(typ)),
             'isnull': dict(),
-            'regex': dict(allowed_types=[graphene.String]),
-            'iregex': dict(allowed_types=[graphene.String]),
+            #'regex': dict(allowed_types=[graphene.String]),
+            #'iregex': dict(allowed_types=[graphene.String]),
             'search': dict(allowed_types=[graphene.String]),
 
             # postgres lookups
@@ -113,7 +112,7 @@ FILTER_FIELDS = R.compose(
             'has_keys': dict(allowed_types=[graphene.JSONString, graphene.InputObjectType]),
             'has_any_keys': dict(allowed_types=[graphene.JSONString, graphene.InputObjectType]),
             # groups of 3 characters for similarity recognition
-            'trigram_similar': dict(allowed_types=[graphene.String])
+            #'trigram_similar': dict(allowed_types=[graphene.String])
         }
     )
 )(settings)
@@ -173,7 +172,7 @@ def _memoize(args):
 
 
 @memoize(map_args=_memoize)
-def input_type_class(field_config, crud, parent_type_classes=[], allowed_fields_only=False):
+def input_type_class(field_config, crud, parent_type_classes=[], fields_only=False, with_filter_fields=True):
     """
     An InputObjectType subclass for use as nested query argument types and mutation argument types
     The subclass is dynamically created based on the field_dict_value['graphene_type'] and the crud type.
@@ -184,6 +183,11 @@ def input_type_class(field_config, crud, parent_type_classes=[], allowed_fields_
     :param parent_type_classes: String or String array of parent graphene type classes. Unfortunately, Graphene doesn't
     let us reuse input types around the schema, even if they are identical, so we must give them unique names
     based on the parent ancestry
+    :param fields_only Default False. Don't create the inpub class, just return the fields that are created,
+    including filter fields. This is like calling fields_with_filter_fields with a bit of prep
+    :param with_filter_fields Default True. If False don't create filter fields. Only needed for things like
+    pagination and version types where we don't want filters on the top level properties like page number, but
+    do want it recursively on the objects property
     :return: An InputObjectType subclass
     """
     # Get the Graphene type. This comes from graphene_type if the class containing the field is a Django Model,
@@ -196,8 +200,8 @@ def input_type_class(field_config, crud, parent_type_classes=[], allowed_fields_
     modified_parent_type_classes = parent_type_classes if R.isinstance((list, tuple), parent_type_classes) else [
         parent_type_classes]
 
-    combined_fields = fields_with_filter_fields(fields, graphene_class, modified_parent_type_classes, crud)
-    if allowed_fields_only:
+    combined_fields = fields_with_filter_fields(fields, graphene_class, modified_parent_type_classes, crud, with_filter_fields)
+    if fields_only:
         return combined_fields
 
     return type(
@@ -220,7 +224,7 @@ def input_type_class(field_config, crud, parent_type_classes=[], allowed_fields_
     )
 
 
-def fields_with_filter_fields(fields, graphene_class, parent_type_classes=[], crud=None):
+def fields_with_filter_fields(fields, graphene_class, parent_type_classes=[], crud=None, with_filter_fields=True):
     """
         Adds filter fields to the given fields, so that for field name we add nameContains etc.
         This is used for search arguments as well as search class instances which can store searches
@@ -229,6 +233,9 @@ def fields_with_filter_fields(fields, graphene_class, parent_type_classes=[], cr
     naming the internal fields. You can also use the class name to avoid self-referencing problems
     :param parent_type_classes: Optional array of parent types when building embedded classes
     :param crud: Optional crud value 'create' or 'update' that remove update and create constraints
+    :param with_filter_fields Default True. If False don't create filter fields. Only needed for things like
+    pagination and version types where we don't want filters on the top level properties like page number, but
+    do want it recursively on the objects property
     :return: The combined fields
     """
 
@@ -261,7 +268,7 @@ def fields_with_filter_fields(fields, graphene_class, parent_type_classes=[], cr
     )
     # These fields allow us to filter on InputTypes when we use them as query arguments
     # This doesn't apply to Update and Create input types, since we never filter during those operations
-    filter_fields = allowed_filter_arguments(input_type_field_configs, graphene_class) if R.equals(READ, crud) else {}
+    filter_fields = allowed_filter_arguments(input_type_field_configs, graphene_class) if with_filter_fields and R.equals(READ, crud) else {}
     # Add 'order_by_field' so the call can specify order by values that match django's syntax or similar
     order_by_field = dict(order_by=String())
     combined_fields = R.merge_all([order_by_field, filter_fields, input_fields])
@@ -537,24 +544,28 @@ def add_filters(argument_dict):
     )(argument_dict)
 
 
-def top_level_allowed_filter_arguments(fields, graphene_type):
+def top_level_allowed_filter_arguments(fields, graphene_type, with_filter_fields=True):
     """
-        For top-level calls, not recursion
-        Like allowed_query_and_read_arguments but only used for arguments and adds filter variables like id_contains.
+        For top-level read calls.
+        Like allowed_filter_arguments but only used for arguments and adds filter variables like id_contains.
         Note that django needs __ so these are converted for resolvers. The graphql interface converts them to
         camel case
     :param fields: The fields for the graphene type
     :param graphen_type: The graphene type
+    :param with_filter_fields Default True. If False don't create filter fields. Only needed for things like
+    pagination and version types where we don't want filters on the top level properties like page number, but
+    do want it recursively on the objects property
     :return: dict of field keys and there graphene type, either a primitive or input type
     """
-    return input_type_class(dict(fields=fields, graphene_type=graphene_type), 'read', [], True)
+    return input_type_class(
+        dict(fields=fields, graphene_type=graphene_type),
+        'read', [], fields_only=True, with_filter_fields=with_filter_fields
+    )
 
 
 def allowed_filter_arguments(fields_dict, graphene_type):
     """
-        Like allowed_query_and_read_arguments but only used for arguments and adds filter variables like id_contains.
-        Note that django needs __ so these are converted for resolvers. The graphql interface converts them to
-        camel case
+        Used internally by calls started by top_level_allowed_filter_arguments
     :param fields_dict: The fields_dict for the Django model
     :param graphen_type: Type used for embedded input class naming
     :return: dict of field keys and there graphene type, either a primitive or input type
